==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/plugin/lang/zh-tw/lang.php <==
<?php
/**
 * Chinese Traditional language file
 *
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin
 * @author Shuo-Ting Jian <shoting@gmail.com>
 */
$lang['menu']                  = '管理插件 (Plugins)';
$lang['download']              = '下載與安裝插件';
$lang['manage']                = '已安裝的插件';
$lang['btn_info']              = '資訊';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '刪除';
$lang['btn_settings']          = '設定';
$lang['btn_download']          = '下載';
$lang['btn_enable']            = '儲存';
$lang['url']                   = 'URL';
$lang['installed']             = '安裝:';
$lang['lastupdate']            = '上次更新:';
$lang['source']                = '來源：';
$lang['unknown']               = '未知';
$lang['updating']              = '更新中 ...';
$lang['updated']               = '插件 %s 成功地更新';
$lang['updates']               = '以下的插件已經成功地更新';
$lang['update_none']           = '找不到更新';
$lang['deleting']              = '刪除中 ...';
$lang['deleted']               = '插件 %s 已刪除。';
$lang['downloading']           = '下載中 ...';
$lang['downloaded']            = '插件 %s 已成功地安裝';
$lang['downloads']             = '以下的插件已成功地安裝:';
$lang['download_none']         = '找不到插件，或在下載與安裝時發生了未知的問題';
$lang['plugin']                = '插件:';
$lang['components']            = '元件';
$lang['noinfo']                = '此插件沒有回傳任何資訊，可能是無效的';
$lang['name']                  = '名稱:';
$lang['date']                  = '日期:';
$lang['type']                  = '類型:';
$lang['desc']                  = '描述:';
$lang['author']                = '作者:';
$lang['www']                   = '網頁:';
$lang['error']                 = '一個未知的錯誤發生。';
$lang['error_download']        = '無法下載插件檔案: %s';
$lang['error_badurl']          = 'URL 可能有問題 - 從 URL 中無法得知文件名';
$lang['error_dircreate']       = '無法建立暫存目錄來接收下載的內容';
$lang['error_decompress']      = '插件管理器無法解壓下載的文件。這可能是由於下載出現錯誤，遇到這種情況，請您再次嘗試;或者是壓縮格式無法識別，遇到這種情況，您需要手動下載並安裝該插件。';
$lang['error_copy']            = '嘗試安裝插件 <em>%s</em> 的相關文件時發生複製錯誤：可能是磁碟空間不足或檔案存取權限錯誤。這可能是由於未安裝完全的插件使維基系統不穩定導致。';
$lang['error_delete']          = '嘗試刪除插件 <em>%s</em> 時發生錯誤。最可能原因是檔案或目錄存取權限不足';
$lang['enabled']               = '插件 %s 已啟用。';
$lang['notenabled']            = '插件 %s 無法啟用，請檢查檔案權限。';
$lang['disabled']              = '插件 %s 已停用。';
$lang['notdisabled']           = '插件 %s 無法停用，請檢查檔案權限。';
$lang['packageinstalled']      = '插件 (%d 插件%s: %s) 已成功地安裝。';

==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/zh-tw/lang.php <==
<?php
/**
 * Chinese Traditional language file
 *
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata@gmail.com
 */
$lang['menu']                  = '管理插件 (Plugins)';
$lang['download']              = '下載與安裝插件';
$lang['manage']                = '已安裝的插件';
$lang['btn_info']              = '資訊';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '刪除';
$lang['btn_settings']          = '設定';
$lang['btn_download']          = '下載';
$lang['btn_enable']            = '儲存';
$lang['url']                   = 'URL';
$lang['installed']             = '安裝：';
$lang['lastupdate']            = '上次更新：';
$lang['source']                = '來源：';
$lang['unknown']               = '未知';
$lang['updating']              = '更新中 ...';
$lang['updated']               = '插件 %s 成功地更新';
$lang['updates']               = '以下的插件已經成功地更新';
$lang['update_none']           = '找不到更新';
$lang['deleting']              = '刪除中 ...';
$lang['deleted']               = '插件 %s 已刪除。';
$lang['downloading']           = '下載中 ...';
$lang['downloaded']            = '插件 %s 已成功地安裝';
$lang['downloads']             = '以下的插件已成功地安裝:';
$lang['download_none']         = '找不到插件，或在下載與安裝時發生了未知的問題';
$lang['plugin']                = '插件：';
$lang['components']            = '元件';
$lang['noinfo']                = '此插件沒有回傳任何資訊，可能是無效的';
$lang['name']                  = '名稱：';
$lang['date']                  = '日期：';
$lang['type']                  = '類型：';
$lang['desc']                  = '描述：';
$lang['author']                = '作者：';
$lang['www']                   = '網頁:';
$lang['error']                 = '一個未知的錯誤發生。';
$lang['error_download']        = '無法下載插件檔案： %s';
$lang['error_badurl']          = 'URL 可能有問題 - 從 URL 中無法得知文件名';
$lang['error_dircreate']       = '無法建立暫存目錄來接收下載的內容';
$lang['error_decompress']      = '插件管理器無法解壓下載的文件。這可能是由於下載出現錯誤，遇到這種情況，請您再次嘗試;或者是壓縮格式無法識別，遇到這種情況，您需要手動下載並安裝該插件。';
$lang['error_copy']            = '嘗試安裝插件 <em>%s</em> 的相關文件時發生複製錯誤：可能是磁碟空間不足或檔案存取權限錯誤。這可能是由於未安裝完全的插件使維基系統不穩定導致。';
$lang['error_delete']          = '嘗試刪除插件 <em>%s</em> 時發生錯誤。最可能原因是檔案或目錄存取權限不足';
$lang['enabled']               = '插件 %s 已啟用。';
$lang['notenabled']            = '插件 %s 無法啟用，請檢查檔案權限。';
$lang['disabled']              = '插件 %s 已停用。';
$lang['notdisabled']           = '插件 %s 無法停用，請檢查檔案權限。';
$lang['packageinstalled']      = '插件 (%d 插件%s: %s) 已成功地安裝。';
